# CVER

A simple commandline app for searching and looking up opensource vulnerabilities

# Installation

## Using Pip

```bash
$ pip install cver
```

## Manual 

```bash
$ git clone https://github.com/citguru/cevr
$ cd cver
$ python setup.py install
```

# Usage

```bash
$ cver
```

## Search

`search <keyword>`

```bash
$ cver search python
```

## Lookup

`search <name>`

```bash
$ cver look-up CVE-2020-2121
```


